function [Gmra] = AddThermalAndPressureCorrection(X,Y,AgeGrid,proj,CrustThickness, ZMoho, gt, filePathForTransitionArea);
%       [Gmra] = AddThermalAndPressureCorrection(X,Y,AgeGrid,proj,CrustThickness, ZMoho, gt, filePathForTransitionArea);
% c
% c  add the gravity effect of density change by thermal expansion at the 
% c  lithospheric mantle (125km depth to Moho).
% c
% c  Input parameters:
% c    X - X cooridates for grid/3D model, in km. 
% c    Y - Y cooridates for grid/3D model, in km. 
% c    AgeGrid - oceanic crustal age, its value is null at the continent. 
% c    proj - projection information, for the target paper it is Mercator
% c         projectoin
% c    CrustThickness - crut thickness from the normal gravity inversion
% c      (removing the gravity effect of seawater and sediment; assuming 
% c       mantle density is  constant, for example 3.3g/cc)
% c    ZMoho - Moho interface grid, in km. 
% c    gt - residual gravity anomaly by conventional methods (constant mantle density)
% c    filePathForTransitionArea - the file path for the ESRI shapefile,
% c       which stands for the boundary of transition area, the crustal age
% c       in this area will be interpolated linearly from continent age to
% c        oceanic age.
% c
% c  Output parameters:
% c    Gmra - mantal residual gravity anomaly after adding lithospheric
% c          mantle thermal correction,  in mGal


%%
%the Beta grid
BetaGrid = 30./CrustThickness;
BetaGrid (BetaGrid < 1) = 1;
BetaGrid (~isnan(AgeGrid)) = 1000;

%% LITHOSPHERE THERMAL GRAVITY CORRECTION
% This shapefile contains polygons delineating 'certain' oceanic crust
% (where we will use age grid to calculate thermal correction), and
% 'unstretched' continental crust. Density structure is ramped in area in
% between, as is estimated thinning factor.
if nargin == 8
    [s] = shaperead(filePathForTransitionArea);
    [iAgeGrid] = MakeRegionalOCTGrid(X*1000,Y*1000,AgeGrid,s,300);
    
    % Smoothing of age grid in case of artefacts
    iAgeGrid = han3(iAgeGrid,3);
else
    AgeGrid(isnan(AgeGrid)) = 300;
    iAgeGrid = AgeGrid;
end


%lithospheric mantle density
rho = 3300;

%create the surface for each layer of the lithospheric mantle (from 125km depth to Moho surface)
layersNum = 20;
[m n] = size(ZMoho);
z = zeros(m, n ,layersNum);
z(:,:,1) = ZMoho - min(min(ZMoho)) + 2;

for layerindex = 2:layersNum
    deltaZ = (125 - z(:,:,1))/layersNum;
    z(:,:,layerindex) =  z(:,:,layerindex - 1) + deltaZ;
end

%%
%add thermal correction
% Calculate the thermal gravity correction 
[grv,Tz,P, Rho] = ThermalAndPressureGravityAnomaly(X,Y,z,BetaGrid,iAgeGrid, layersNum, rho);
deltaRho = Rho - rho;

% Add thermal correction to gravity data
Gmra = gt-grv;
% save WithThermalAndPressureCorrection
% 
% 
% % %
% %add thermal correction
% % Calculate the thermal gravity correction 
% [grv_thermal,Tz,deltaRhoThermal] = ThermalGravityAnomaly_McKenzie1978(X,Y,z,BetaGrid,iAgeGrid, layersNum, rho);
% % [grv_thermal,Tz,deltaRhoThermal] = ThermalGravityAnomaly_McKenzie2005(X,Y,z,BetaGrid,iAgeGrid, layersNum, rho);
% 
% % Add thermal correction to gravity data
% Gmra = gt-grv_thermal;
% 
% 
% grv_pressure = grv - grv_thermal;
% deltaRhoPressure = deltaRho - deltaRhoThermal;
% 
% save WithThermalCorrection
% d = 9;

