function [RMS] = InversionLoop(CRhoList, ZRefList, X, Y, Gmra, bsmt, pVX, pVY, pSeisStandard, compareMohoOrCrust);
%       [RMS] = InversionLoop(CRhoList, ZRefList, X, Y, Gmra, bsmt, pVX, pVY, pSeisStandard, compareMohoOrCrust);
% c
% c  invert crustal thickness/Moho depth with different background density
% c       and reference depth, and get the RMS value for each background density
% c       and reference depth. The RMS will be used for choosing the best
% c       parameters for inversion
% c
% c  Input parameters:
% c    CRhoList - candidate background / crust density list, in kg/m^3
% c    ZRefList - candidate reference depth list, in km
% c    X - X cooridates for grid/3D model, in km. 
% c    Y - Y cooridates for grid/3D model, in km. 
% c    Gmra - gravity mantle residual anomaly, in mGal (after adding thermal and pressure corrections)
% c    bsmt - basement interface ,in km 
% c    pVX - X coordinates for the seismic stations ,in km 
% c    pVY - Y coordinates for the seismic stations ,in km 
% c    pSeisStandard - crustal thickness or Moho depth depends on
% c          'compareMohoOrCrust', in km
% c    compareMohoOrCrust - illustrate 'pSeisStandard' is crustal thickness or Moho depth
% c
% c  Output parameters:
% c    RMS - RMS between seismic result and inversion result for each
% c          combanition of reference depth and background density


for i=1: max(size(CRhoList))
    for j=1: max(size(ZRefList))
        
        % Density contrast in g/cm3
        MohoDensityContrast=3.3-CRhoList(i);
        
        % Reference Moho depth around edge of basin
        ZRef = ZRefList(j);
        
        % invert for Moho Depth
        deltaRhoMoho = MohoDensityContrast;
        [ZMoho] = oldenburg(X,Y,Gmra-mean(Gmra(:)),-deltaRhoMoho,1);
        
        
        %% Reference depth adjustment
        ZMoho = ZMoho+ZRef;    
        
        %% compare inversion result with seismic data
        % get the inversion data which will be compared to seismic result   
        if findstr(compareMohoOrCrust,'Moho')
            pGravResult = interp2(X.*1000,Y.*1000,ZMoho,pVX,pVY,'linear');        
        else
            pGravResult = interp2(X.*1000,Y.*1000,ZMoho-bsmt,pVX,pVY,'linear');    
        end
       
        % calculating the RMS between inversion and seismic
        tmp = pGravResult-pSeisStandard;
        m = max(size(tmp));
        x = tmp'*tmp / m;
        RMS(i,j) = sqrt(x);
        
    end
end





