function [CrustThickness pGravResult] = Inversion_WithThermalCorrection(backgroundDensity, zefD, X, Y, Gmra, bsmt, pVX, pVY, pSeisStandard,compareMohoOrCrust);
%       Inversion_WithThermalCorrection(backgroundDensity, zefD, X, Y, Gmra, bsmt, pVX, pVY, pSeisStandard,compareMohoOrCrust);
% c
% c  invert crustal thickness with the resitual anomaly which has been
% c    added thermal and pressure correction
% c     anomaly
% c
% c  Input parameters:
% c    backgroundDensity - background / crust density, in kg/m^3
% c    zefD - reference depth, in km
% c    X - X cooridates for grid/3D model, in km. 
% c    Y - Y cooridates for grid/3D model, in km. 
% c    Gmra - gravity mantle residual anomaly, in mGal (after adding thermal and pressure corrections)
% c    bsmt - basement interface ,in km 
% c    pVX - X coordinates for the seismic stations ,in km 
% c    pVY - Y coordinates for the seismic stations ,in km 
% c    pSeisStandard - crustal thickness or Moho depth depends on
% c          'compareMohoOrCrust', in km
% c    compareMohoOrCrust - illustrate 'pSeisStandard' is crustal thickness or Moho depth
% c
% c  Output parameters:
% c    CrustThickness - crustal thickness with thermal and pressure
% c           correction
% c    pGravResult - the  crustal thickness or Moho depth at the same
% c         station with seismic


% density contrast for Moho
MohoDensityContrast=3.3 - backgroundDensity;

%% invert for Moho Depth
deltaRhoMoho = MohoDensityContrast;
[ZMoho] = oldenburg(X,Y,Gmra-mean(Gmra(:)),-deltaRhoMoho,1);

%% Reference depth adjustment
ZMoho = ZMoho+zefD;
CrustThickness = ZMoho-bsmt;



%%
% PLOTTING CrustThickness
figure
imagesc(X,Y,CrustThickness)
axis equal tight xy
colormap(jet)
colorbar
hold on
contour(X,Y,CrustThickness,[0:2.5:40],'k')
title('crustal Thickness (km)')
print('-dpdf', '-painters', 'Fig1_crustalThickness.pdf');


%% compare inversion result with seismic data
% get the inversion data which will be compared to seismic result
if findstr(compareMohoOrCrust,'Moho')
    pGravResult = interp2(X.*1000,Y.*1000,ZMoho,pVX,pVY,'linear'); 
else
    pGravResult = interp2(X.*1000,Y.*1000,ZMoho-bsmt,pVX,pVY,'linear');
end

% calculating the RMS between inversion and seismic
tmp = pSeisStandard-pGravResult;
m = max(size(tmp));
x = tmp'*tmp / m;
RMS = sqrt(x)


%%
% PLOTTING seismic result VS inversion result
figure
hold on
box on
plot(pSeisStandard,pGravResult,'ks','markersize',7,'color',[0.2 0.2 0.2],'markerfacecolor',[1 1 1])
axis([0 40 0 40])
grid on
plot([-5 55],[-5 55],'--','color',[0.5 0.5 0.5],'linewidth',2)
xlabel('Moho from Seismic Interpretation')
ylabel('Moho from Gravity Inversion')


set(gcf,'units','inches')
set(gcf,'position',[.1 .1 11 7.5])
set(gcf,'PaperPositionMode','auto')
set(gcf,'PaperType','A4')
set(gcf,'PaperOrientation','landscape') 
print('-dpdf', '-painters', 'Fig2_GravityVsSeismic.pdf');


%%  PLOTTING the difference between inversion result and seismic result
figure
contour(X,Y,CrustThickness,[0:2:50],'k')
hold on
scatter(pVX./1000,pVY./1000,30,pGravResult-pSeisStandard,'s','filled')
axis equal tight xy
colormap(jet)
caxis([-10 10])
colorbar
title('Gravity CrustThick minus seismic CrustThick (red means Gravity CrustThick too deep)')
xlim([min(X) max(X)]);
ylim([min(Y) max(Y)]);

print('-dpdf', '-painters', 'Fig3_GravityVsSeismic.pdf');


