function [grvtotal,Tz,deltaRhoVolume] = ThermalGravityAnomaly_McKenzie1978(X,Y,z,BetaGrid,AgeGrid,layersNum, rho);
%       [grvtotal,Tz,deltaRhoVolume] = ThermalGravityAnomaly_McKenzie1978(X,Y,z,BetaGrid,AgeGrid,layersNum, rho);
% c
% c  calculate the gravity effect of density change by thermal expansion in the lithospheric mantle (from Moho to
% 125km depth)
% c
% c  Input parameters:
% c    X - X cooridates for grid/3D model, in km. 
% c    Y - Y cooridates for grid/3D model, in km. 
% c    z - interface of each layr of 3D model, in km. 
% c    BetaGrid - beta grid, please check the main paper
% c    AgeGrid - crustal age grid after adding continental crustal age at
% c         the continet area and adding age at the transition area
% c    layersNum - layers number contained by 3D model
% c    rho - mantle constant density, (3.3g/cm^) 
% c
% c  Output parameters:
% c    grvtotal -  the gravity effect of density change by thermal expansion and
% c        pressure-driven compressibility in the lithospheric mantle (from Moho to
% c        125km depth)
% c    Tz - temperature of each layer, in K
% c    deltaRhoVolume - each layer's density change by thermal expansion in the lithospheric mantle (from Moho to
% c        125km depth)

% 
% % Constants
% tau = 62.8; % lithosphere cooling thermal decay constant
% a = 125;    % lithosphere thickness
% Tm = 1333;  % Base lithosphere temparature
% alpha = 3.28e-5;   % coefficient of thermal expansion
% 
% G = 6.67e-11;    % Gravitational constant
% 
% % they are the parameters for thermal expansion coefficient as the linear
% % function of temperature
% alpha0 = 2.832e-5;
% alpha1 = 0.758e-8;
% 
% numtaylor = 8;
% 
% [ny,nx] = size(AgeGrid);
% Tz = zeros(ny,nx,layersNum-1);
% 
% grvtotal = zeros(ny,nx);
% deltaRhoVolume = zeros(ny,nx,layersNum-1);
% 
% for layerindex = 1:layersNum-1
%      
%     % CALCULATE THE GRAVITY ANOMALY USING SUMMATION OF
%     % PARKER FLAT LAYERS
%     % (adapted from mag3dblock.m)
%     disp('starting summation of layers')   
%     
%     %%% temperautre filed (McKenzie, 1978)
%     ConstantTerm1 = 2/pi;
%     NthSum = zeros([ny,nx]);
%     
%     for n = 1:numtaylor
%         NthTerm =  (((-1).^(n+1))/n) .* ((BetaGrid./(n*pi)).*sin((n*pi)./BetaGrid)) ...
%             .* exp((((-n^2)).*AgeGrid)./tau) .* sin((n*pi.*(a - z(:,:,layerindex)))./a);
%         NthSum = NthSum + NthTerm;
%     end
%     Tratio = 1 - (a - z(:,:,layerindex))./a + ConstantTerm1 .*NthSum;
%     T = Tratio.*Tm + 273;
%     Tz(:,:,layerindex) = T;
%     
%     % different methods for calculating thermal expansion
% %     alpha = alpha0 + alpha1.*(T + 273); %Bouhifd et al. (1996)
% %     alpha = 6e-10*T.^3 - 2e-6*T.^2+ 0.0039*T + 1.727;  alpha = alpha * 1e-5;%Kroll2012
% 
%     % density  change by thermal expansion
%     deltaRho = rho.* (- alpha.*T);
%     deltaRhoVolume(:,:,layerindex) = deltaRho;
% 
%     %     for layerindex = 1:layersNum-1
%     z1 = z(:,:,layerindex);
%     z2 = z(:,:,layerindex+1);
%     
%     
%     % gravity of the density change of the target layer
%     grvlayer = parkergrav(X,Y,z2,z1,deltaRho);
%     
%     % gravity effect summation
%     grvtotal = grvtotal+grvlayer;    
%     disp(['done layer ',num2str(layerindex)])
%     
% end

% clear
dx = (abs(X(2)-X(1)))./1000;


%% Constants parameters
tau = 62.8; % lithosphere cooling thermal decay constant
a = 125;    % lithosphere thickness
Tm = 1333;  % Base lithosphere temparature
alpha = 3.28e-5;   % coefficient of thermal expansion

G = 6.67e-11;    % Gravitational constant

% they are the parameters for thermal expansion coefficient as the linear
% function of temperature
alpha0 = 2.832e-5;
alpha1 = 0.758e-8;


numtaylor = 8;

[ny,nx] = size(AgeGrid);

grvtotal = zeros(ny,nx);
deltaRhoVolume = zeros(ny,nx,layersNum-1);
Tz = zeros(ny,nx,layersNum-1);
P = zeros(ny,nx,layersNum-1);

%% calculate the temperature field
for layerindex = 1:layersNum-1
     
    % CALCULATE THE GRAVITY ANOMALY USING SUMMATION OF
    % PARKER FLAT LAYERS
    % (adapted from mag3dblock.m)
    disp('starting summation of layers')   
    
    %%% McKenzie, 1978
    ConstantTerm1 = 2/pi;
    NthSum = zeros([ny,nx]);
    
    for n = 1:numtaylor
        NthTerm =  (((-1).^(n+1))/n) .* ((BetaGrid./(n*pi)).*sin((n*pi)./BetaGrid)) ...
            .* exp((((-n^2)).*AgeGrid)./tau) .* sin((n*pi.*(a - z(:,:,layerindex)))./a);
        NthSum = NthSum + NthTerm;
    end
    Tratio = 1 - (a - z(:,:,layerindex))./a + ConstantTerm1 .*NthSum;
    Tz(:,:,layerindex) = Tratio.*Tm + 273;
    
end

%% calculate the pressure field; gravity effect of therm and pressure
g = 9.8;
toleraceD = 0.0001;
for layerindex = 1:layersNum-1
    disp('starting summation of layers')   
    
    % temprature difference between two neighbouring grids
    if(layerindex == 1)
        deltaT = Tz(:,:,layerindex)-273; % for the top layer
    else
        deltaT = Tz(:,:,layerindex) -  Tz(:,:,layerindex-1);
    end
    
    
   % upper layer density which is on the top of target layer
    if(layerindex == 1)
        rho_top = ones(ny,nx)*rho;
    else
        rho_top = deltaRhoVolume(:,:,layerindex - 1);
    end
    
    % different methods for calculating alfa
%     alpha = alpha0 + alpha1*(Tz(:,:,layerindex));%Bouhifd et al. (1996)
%     T = Tz(:,:,layerindex);    alpha = 6e-10*T.^3 - 2e-6*T.^2+ 0.0039*T + 1.727;  alpha = alpha * 1e-5;%Kroll 2012    
    
    rho_below = rho_top.* (1 - alpha.*deltaT);
     
    deltaRhoVolume(:,:,layerindex) = rho_below;

    % gravity effect of the density change by thermal and pressure effect
    % on the target layer
    z1 = z(:,:,layerindex);
    z2 = z(:,:,layerindex+1);    

    grvlayer = parkergrav(X,Y,z1,z2,rho_below - rho);    
    grvtotal = grvtotal - grvlayer;
    
    disp(['done layer ',num2str(layerindex)])
    
end

deltaRhoVolume = deltaRhoVolume - rho;


