function [grvtotal,vm] = grav3dblock(x,y,srf1,srf2,layers,phi,c,rhoBackground)
%      [grvtotal,vm] = grav3dblock(x,y,srf1,srf2,layers,phi,c,rhoBackground)
% c
% c  calculate the gravity effect of seawater and sediment layer
% c
% c  Input parameters:
% c    x - X cooridates for grid/3D model, in km. 
% c    y - Y cooridates for grid/3D model, in km. 
% c    srf1 - bathymetry grid, when the water depth is 10, the value is 10, in km
% c    srf2 - basement/sediment bottom, when its depth is 10, the value is
% c       10, in km
% c    layers - surface of each layer in the 3D model, in km
% c    phi0 - paramter for the relationship between sediment porosity and
% c         buried depth, see Sawyer 1985
% c    c - paramter for the relationship between sediment porosity and
% c         buried depth, see Sawyer 1985
% c    rhoBackground - background density, in kg/m^3 
% c
% c  Output parameters:
% c    grvtotal - the gravity effect of seawater and sediment layer from free air
% c        anomaly
% c    vm - density of each layer, in kg/m^3 


[m,n] = size(srf1);
dx = abs(x(2)-x(1));

if ~exist('rhoBackground')
    rhoBackground = 0;
end

[vx,vy,vz] = meshgrid(x,y,layers(1:end-1));
vm = zeros(size(vx));


disp('gridding model in 3D....')

% For a each vertical profile within the cube, use logicals to determine
% whether each depth point is below each surface and assign the density
% accordingly
for mapX = 1:n
    for mapY = 1:m
        % force all cells above bathymetry to have water density
        ind  = find(layers<=srf1(mapY,mapX));
        vm(mapY,mapX,ind) = rhoBackground - 1030;
        
        % sedimetn density
        ind = find(layers>srf1(mapY,mapX) & layers<srf2(mapY,mapX));
        if ~isempty(ind)
            ZBelowBathy = layers(ind)-srf1(mapY,mapX);
            [rhoS] = DepthDependentDensity(ZBelowBathy.*1000,phi,c);
            rhoS = rhoBackground-rhoS;
%             rhoS = rhoBackground-2300;
            vm(mapY,mapX,ind) = rhoS;
            
        end        
    end
    disp(['done grav block column ',num2str(mapX)])
end

disp('starting summation of layers')

% summing gravity effect of each layer in the model
grvtotal = zeros(m,n);
for layerindex = 1:length(layers)-1
    z1 = layers(layerindex);
    z2 = layers(layerindex+1);
    grvlayer = glayer(vm(:,:,layerindex),dx,z1,z2);
    
    grvtotal = grvtotal+grvlayer;
    
    disp(['done layer ',num2str(layerindex)])
end





