clear
% This document is for the  matlab codes which belong to the paper Mapping crustal thickness using marine gravity data: methods and uncertainties?for the journal GEOPYSICS.
% Brief introduction
% These codes are for crustal thickness inversion based on marine free air gravity anomaly data with removing sediment gravity effect and also the gravity effect of temperature and pressure variations of the lithospheric mantle from the observed free air gravity anomaly data (See the paper for details and its uncertainty test). With the enough and correct input data, the codes can get the crustal thickness with the best inversion parameters.
% Input data: 
% 1.	The coordinate of four boundary points of interested area with Mercator projection (minX, maxX, minY, maxY)
% 2.	Sampling rate (samp)
% 3.	Wave length for filtering (LPwavelength)
% 
% 4.	Moho density contrast with crust (MohoDensityContrast), the unit is g/cm3
% 5.	The initial guess of suitable values for reference depth (ZRefList) and crust density (CRhoList)
% 
% 6.	GeoTif file with Mercator projection, has been attached
% 
% 7.	Digitized seismic profiles, saved in one point-type shape file (seismicProfiles). The shape file contains the attribute named MohoDepth?which is the Moho depth at the target point with unit km. No projection, location is in longitude and latitude.
% 
% 8.	age data (AgeGrid) with Mercator projection
% 9.	free air anomaly(FAAGrid) with Mercator projection
% 10.	bathymetry (BathyGrid) with Mercator projection
% 11.	sediment thickness (SedThickGrid) with Mercator projection
% 
% 12.	The parameter for sediment porosity-depth function.
% 
% 13.	Digitized polygon-type shape file (ESRI *.shp) which is the border of transition zone?(filePathForTransitionArea). The shape file contains the attribute named Type? it stands for oceanward boundary of this zone when its value is 1; it stands for landward boundary of this zone when its value is 2. No projection, location is in longitude and latitude. The file has been attatched; please check the paper for profiles sources. 
% Running method:
% 1.	Run the main function crustalThicknessInversionWithThermalAndPressureCorrection?
% 2.	Digitize the boundaries of transition zone?according to the inversion result without thermal and pressure effect corrections.
% 3.	Take the digitized the file in step 2 as the input file and continue the main function.
% 4.	The best parameters for inversion can be derived according to the comparison between gravity inversion and seismic interpretations. The final inversion result is based on these parameters.
% 5.	The crustal thickness and Moho depth will be saved in netcdf files with Mercator projection and also with longitude and latitude.



%% add paths for functions
addpath BasicFunctions
addpath CorrectionFunctions

%% input files
ageGridFile = 'Data\AgeGrid.nc';
gravityGridFile = 'Data\FAAGrid.nc';
bathyGridFile = 'Data\BathyGrid.nc';
sedThickGridFile = 'Data\SedThickGrid.nc';

% ageGridFile = 'D:\LeoThings\MatlabGravityInversion\GridFiles\agegrid_5km.nc';
% gravityGridFile = 'D:\LeoThings\MatlabGravityInversion\GridFiles\Sandwell_grav18.1_BAFA_5km.nc';
% bathyGridFile = 'D:\LeoThings\MatlabGravityInversion\GridFiles\DNSC08BAT_5km.nc';
% sedThickGridFile = 'D:\LeoThings\MatlabGravityInversion\GridFiles\NGDCcrust2_SedThick_2011_5km.nc';

% geo tif for the projection
proj=geotiffinfo('Data\tifForProjection.tif');

% reference seismic profiles
seismicProfiles=shaperead('Data\seismicLinesSummerize.shp');

% digitized polyline file for boundarying the transition area
filePathForTransitionArea = 'Data\transitionZone.shp'%'D:\LeoThings\MatlabGravityInversion\OCB2013\DataFiles\TransitionPart.shp';%

%% input parameters

% SPECIFY AREA OF INTEREST
minX = 110e5;
maxX = 140e5;
minY = 0;
maxY = 30e5;

minLongitude = 104;
maxLongitude = 123;
minLatitude = 0;
maxLatitude = 27;

% sampling interval and filtering wavelength
samp=1;
LPwavelength = 60; % km

% background density variation
minRho = 2.6; % minimum background density
maxRho = 3.0;% maximum background density
numRho = 8; % the numbers for candidate background dneisty
CRhoList = [minRho: (maxRho-minRho)/(numRho - 1): maxRho]; %  background dneisty list

% reference dpeth variation
minRef = 18;% minimum reference depth
maxRef = 38;% maximum reference depth
numRef = 10;% the numbers for candidate reference depth
ZRefList = [minRef: (maxRef-minRef)/(numRef - 1): maxRef];%  reference depth list

%parameters for sedimetn porosity-depth function from sawyer 1985
phi0 = 0.55;
c=4.5e-4;

% Density contrast for mantle in g/cm3
MohoDensityContrast=3.3-2.7;


%% LOAD DATA SETS

% Age Grid
[AgeGrid,Xmeter,Ymeter] = getcdf(ageGridFile,samp,[minX maxX minY maxY]);

% Gravity Grid - Free-Air offshore, Bouguer Anomaly Onshore
[FAAGrid,X,Y] = getcdf(gravityGridFile, samp,[minX maxX minY maxY]);

% Bathymetry (negative downwards)
[BathyGrid,X,Y] = getcdf(bathyGridFile,samp,[minX maxX minY maxY]);

% Sediment thickness 
[SedThickGrid,X,Y] = getcdf(sedThickGridFile,samp,[minX maxX minY maxY]);

% cdfwrite2(Xmeter,Ymeter,AgeGrid,['Data\AgeGrid.nc']);
% cdfwrite2(X,Y,FAAGrid,['Data\FAAGrid.nc']);
% cdfwrite2(X,Y,BathyGrid,['Data\BathyGrid.nc']);
% cdfwrite2(X,Y,SedThickGrid,['Data\SedThickGrid.nc']);

% convert the unit from meter to km
X = X./1000;
Y = Y./1000;

% create longitude and latitude grid
GLong = [minLongitude:(2/60):maxLongitude];
GLat = [minLatitude:(2/60):maxLatitude];
[GridLong,GridLat] = meshgrid(GLong,GLat);
[GridLong,GridLat] = projfwd(proj,GridLat,GridLong);

%% Forward_NoThermal

% remove gravity effect of seawater and sediment; 
% gt is the residual anomaly
% bsmt is basement surface
[gt bsmt] = Forward_NoThermalAndPressureCorrection(FAAGrid, BathyGrid, SedThickGrid, X, Y,phi0 ,c);

%% invert withouth thermal correction

% Filter the gravity grid to remove short-wavelength noise
% [gt] = gridfilter(X,Y,gt,[],LPwavelength,1);

% invert for Moho Depth
[ZMoho] = oldenburg(X,Y,gt-mean(gt(:)),-MohoDensityContrast,1);

% ajust Moho depth by reference depth
ZMoho = ZMoho + max(max(bsmt))+2;

% crustal thickness
CrustThickness = ZMoho - bsmt;

% output crstal thickness withou thermal and pressure correction, which is
% useful for digitizing the boundary of transition area
ZMohoLL = interp2(X.*1000,Y.*1000,ZMoho,GridLong,GridLat,'linear');
CrustThicknessLL = interp2(X.*1000,Y.*1000,CrustThickness,GridLong,GridLat,'linear');
cdfwrite2(GLong,GLat,ZMohoLL,['crustThicknessNoThermPressCorrec_LongitudeLatitue.nc']);

%% Forward_AddThermal

% remove thermal and pressure gravity effect from residual anomaly
Gmra = AddThermalAndPressureCorrection(X,Y,AgeGrid,proj,CrustThickness,ZMoho, gt, filePathForTransitionArea);

%% InversionLoop
% reference seismic profiles
[pX,pY] = projfwd(proj,vertcat(seismicProfiles.Y),vertcat(seismicProfiles.X));

pSeisMoho = vertcat(seismicProfiles.MohoDepth);
isValidMoho = find(pSeisMoho>0);

seismicProfiles = seismicProfiles(isValidMoho);
[pVX,pVY] = projfwd(proj,vertcat(seismicProfiles.Y),vertcat(seismicProfiles.X));
pSeisStandard = vertcat(seismicProfiles.MohoDepth); % effective seismic boundary depth

% the RMS for each combanition of background dnesity and reference depth
RMS = InversionLoop(CRhoList, ZRefList, X, Y, Gmra, bsmt, pVX, pVY, pSeisStandard ,'Moho'); 
% csvwrite('RMS-constant.dat',RMS)
% csvwrite('RMS-linear.dat',RMS)
% csvwrite('RMS-polynomial.dat',RMS)
% csvwrite('RMS-TP.dat',RMS)

%% get the final result with best paramters
[m n]=find(RMS==min(min(RMS)))
disp(['best value for crust density is ' num2str(CRhoList(m)) ' g/cc'])   
disp(['best value for reference depth is ' num2str(ZRefList(n)) ' km'])  

%final crustal thickness with best background density and reference depth
[CrustThickness pGravResult_LL]= Inversion_WithThermalCorrection(CRhoList(m), ZRefList(n), X, Y, Gmra, bsmt, pVX, pVY, pSeisStandard,'Moho');

%% save the final result

% in Mercator projection
cdfwrite2(X*1000,Y*1000,CrustThickness,['CrustalThickness_Mercator',num2str(ZRefList(n)),'km_rho',num2str(CRhoList(m)),'.nc']); 
cdfwrite2(X*1000,Y*1000,ZMoho,['MohoDepth_Mercator',num2str(ZRefList(n)),'km_rho',num2str(CRhoList(m)),'.nc']); 
cdfwrite2(X*1000,Y*1000,31./ZMoho,['ThinningFactorMercator',num2str(ZRefList(n)),'km_rho',num2str(CRhoList(m)),'.nc']); 

% in logitude and latitude
ZMohoLL = interp2(X.*1000,Y.*1000,ZMoho,GridLong,GridLat,'linear');
CrustThicknessLL = interp2(X.*1000,Y.*1000,CrustThickness,GridLong,GridLat,'linear');
thiningFactor = CrustThicknessLL./31;
cdfwrite2(GLong,GLat,ZMohoLL,['MohoDepth_LongitudeLatitue',num2str(ZRefList(n)),'km_rho',num2str(CRhoList(m)),'.nc']);
cdfwrite2(GLong,GLat,CrustThicknessLL,['CrustalThickness_LongitudeLatitue',num2str(ZRefList(n)),'km_rho',num2str(CRhoList(m)),'.nc']); 
cdfwrite2(GLong,GLat,thiningFactor,['ThinningFactor_LongitudeLatitue',num2str(ZRefList(n)),'km_rho',num2str(CRhoList(m)),'.nc']); 

% %% output different between crustal thickness form inversion and seismic
% sample = 6;
% FLArray.Grav_SeisCrust = (pGravResult_LL(1:sample:end) - pSeisStandard(1:sample:end));
% Pts2Shapefile('Grav_SeisCrust.shp',[vertcat(seismicProfiles(1:sample:end).X),vertcat(seismicProfiles(1:sample:end).Y)],FLArray);